import { useDayjs } from "@/composables/useDayjs";
import type { FileUploadDestination,LessonTask  } from "@/types/api/lesson";

export const extractLessonStage = (lesson: LessonTask) => {
  const stages = {
    script_upload: !!lesson?.scriptUploadTime,
    script_confirm: !!lesson?.scriptConfirmTime,
    video_capture: !!lesson?.videoCaptureTime,
    post_production: !!lesson?.videoConfirmTime,
    step: 0,
  };
  stages.step = Object.values(stages).filter((v) => v).length;
  return stages;
};

export const calcLessonProgress = (lesson: LessonTask) => {
  if (!lesson) return 0;
  
  // 根据 progressStatus 计算进度
  // 0-脚本上传, 1-脚本确认, 2-视频拍摄, 3-后期制作, 4-任务完成
  switch (lesson.progressStatus) {
    case 4: // 任务完成
      return 100;
    case 3: // 后期制作
      return 75;
    case 2: // 视频拍摄
      return 50;
    case 1: // 脚本确认
      return 25;
    case 0: // 脚本上传
      return 0;
    default:
      return 0;
  }
};

export const getLessonSteps = (lesson: LessonTask, simplify: boolean = false) => {
  const dayjs = useDayjs();
  const dateFormat = "YYYY-MM-DD HH:mm:ss";
  const progress = extractLessonStage(lesson);

  const formatTime = (timestamp?: number | null) => {
    if (!timestamp) return '-';
    return dayjs(timestamp * 1000).format(dateFormat);
  };

  return [
    {
      title: progress.script_upload ? "脚本提交" : undefined,
      description: progress.script_upload
        ? simplify
          ? "已完成"
          : `已于 ${formatTime(lesson.scriptUploadTime)} 完成上传`
        : "脚本文件提交",
    },
    {
      title: progress.script_confirm ? "脚本确认" : undefined,
      description: progress.script_confirm
        ? simplify
          ? "已完成"
          : `已于 ${formatTime(lesson.scriptConfirmTime)} 完成确认`
        : "脚本文件确认",
    },
    {
      title: progress.video_capture ? "视频拍摄" : undefined,
      description: progress.video_capture
        ? simplify
          ? "已完成"
          : `已于 ${formatTime(lesson.videoCaptureTime)} 完成上传`
        : "视频拍摄提交",
    },
    {
      title: progress.post_production ? "后期制作" : undefined,
      description: progress.post_production
        ? simplify
          ? "已完成"
          : `已于 ${formatTime(lesson.videoConfirmTime)} 完成上传`
        : "视频后期制作",
    },
  ];
};

export const getScriptFile = (lesson: LessonTask) => {
  const scriptFile = lesson.script_file ? lesson.script_file.split("|") : [];
  return {
    way: scriptFile[0] || null,
    reupload: scriptFile[1] || null,
  };
};

export const parseCombinedFileString = (
  lesson: LessonTask,
  // key: keyof Pick<LessonTask, "script_file" | "capture_file" | "material_file">
  key: keyof Pick<LessonTask, "advise">
): {
  method: FileUploadDestination | undefined;
  uploaded: boolean;
} => {
  const value = lesson[key];
  if (!value) {
    return {
      method: undefined,
      uploaded: false,
    };
  }
  try {
    const parsed = JSON.parse(value);
    return {
      method: (parsed.method as FileUploadDestination) || undefined,
      uploaded: !!parsed.uploaded,
    };
  } catch {
    return {
      method: undefined,
      uploaded: false,
    };
  }
};
